@@ -1,15 +1,12 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>         *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later                             *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef BOOKMARKSMANAGER_H
 #define BOOKMARKSMANAGER_H
 
 #include <QObject>
+#include <QUrl>
 
 #include "dbmanager.h"
 
@@ -25,13 +22,13 @@ class BrowserManager : public QObject
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString initialUrl READ initialUrl WRITE setInitialUrl NOTIFY initialUrlChanged)
+    Q_PROPERTY(QUrl initialUrl READ initialUrl WRITE setInitialUrl NOTIFY initialUrlChanged)
 
 public:
     static BrowserManager *instance();
 
-    QString initialUrl() const;
-    void setInitialUrl(const QString &initialUrl);
+    QUrl initialUrl() const;
+    void setInitialUrl(const QUrl &initialUrl);
 
     bool isBookmarked(const QString &url) const;
 
@@ -48,6 +45,7 @@ public slots:
 
     void addToHistory(const QVariantMap &pagedata);
     void removeFromHistory(const QString &url);
+    void clearHistory();
 
     void updateLastVisited(const QString &url);
     void updateIcon(const QString &url, const QString &iconSource);
@@ -58,7 +56,7 @@ private:
 
     DBManager *m_dbmanager;
 
-    QString m_initialUrl;
+    QUrl m_initialUrl;
 
     static BrowserManager *s_instance;
 };
