@@ -51,7 +51,7 @@ int DBManager::version()
 {
     QSqlQuery query(QStringLiteral("PRAGMA user_version"));
     if (query.next()) {
-        bool ok;
+        bool ok = false;
         int value = query.value(0).toInt(&ok);
         if (ok)
             return value;
@@ -172,6 +172,15 @@ void DBManager::removeRecord(const QString &table, const QString &url)
     emit databaseTableChanged(table);
 }
 
+void DBManager::removeAllRecords(const QString &table)
+{
+    QSqlQuery query;
+    query.prepare(QStringLiteral("DELETE FROM %1").arg(table));
+    execute(query);
+
+    emit databaseTableChanged(table);
+}
+
 bool DBManager::hasRecord(const QString &table, const QString &url) const
 {
     QSqlQuery query;
@@ -243,6 +252,11 @@ void DBManager::removeFromHistory(const QString &url)
     removeRecord(QStringLiteral("history"), url);
 }
 
+void DBManager::clearHistory()
+{
+    removeAllRecords(QStringLiteral("history"));
+}
+
 void DBManager::updateLastVisited(const QString &url)
 {
     setLastVisitedRecord(QStringLiteral("bookmarks"), url);
