@@ -1,11 +1,7 @@
-/***************************************************************************
- *                                                                         *
- *   SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>           *
- *   SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>          *
- *                                                                         *
- *   SPDX-License-Identifier: GPL-2.0-or-later                             *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
+// SPDX-FileCopyrightText: 2020 Rinigus <rinigus.git@gmail.com>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DBMANAGER_H
 #define DBMANAGER_H
@@ -36,6 +32,7 @@ public:
 
     void addToHistory(const QVariantMap &pagedata);
     void removeFromHistory(const QString &url);
+    void clearHistory();
 
     void updateIcon(const QString &url, const QString &iconSource);
     void updateLastVisited(const QString &url);
@@ -61,6 +58,7 @@ private:
     // methods for manipulation of bookmarks or history tables
     void addRecord(const QString &table, const QVariantMap &pagedata);
     void removeRecord(const QString &table, const QString &url);
+    void removeAllRecords(const QString &table);
     void updateIconRecord(const QString &table, const QString &url, const QString &iconSource);
     void setLastVisitedRecord(const QString &table, const QString &url);
     bool hasRecord(const QString &table, const QString &url) const;
